==> zio-aws-resourcegroups_2.12-5.17.158.2-sources.jar: zio/aws/resourcegroups/model/GetGroupQueryRequest.scala <==
package zio.aws.resourcegroups.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.resourcegroups.model.primitives.{GroupString, GroupName}
import scala.jdk.CollectionConverters._
final case class GetGroupQueryRequest(
    groupName: Option[GroupName] = None,
    group: Option[GroupString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest = {
    import GetGroupQueryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest
      .builder()
      .optionallyWith(
        groupName.map(value => GroupName.unwrap(value): java.lang.String)
      )(_.groupName)
      .optionallyWith(
        group.map(value => GroupString.unwrap(value): java.lang.String)
      )(_.group)
      .build()
  }
  def asReadOnly: zio.aws.resourcegroups.model.GetGroupQueryRequest.ReadOnly =
    zio.aws.resourcegroups.model.GetGroupQueryRequest.wrap(buildAwsValue())
}
object GetGroupQueryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.resourcegroups.model.GetGroupQueryRequest =
      zio.aws.resourcegroups.model.GetGroupQueryRequest(
        groupName.map(value => value),
        group.map(value => value)
      )
    def groupName: Option[GroupName]
    def group: Option[GroupString]
    def getGroupName: ZIO[Any, AwsError, GroupName] =
      AwsError.unwrapOptionField("groupName", groupName)
    def getGroup: ZIO[Any, AwsError, GroupString] =
      AwsError.unwrapOptionField("group", group)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest
  ) extends zio.aws.resourcegroups.model.GetGroupQueryRequest.ReadOnly {
    override val groupName: Option[GroupName] = scala
      .Option(impl.groupName())
      .map(value => zio.aws.resourcegroups.model.primitives.GroupName(value))
    override val group: Option[GroupString] = scala
      .Option(impl.group())
      .map(value => zio.aws.resourcegroups.model.primitives.GroupString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest
  ): zio.aws.resourcegroups.model.GetGroupQueryRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-resourcegroups_2.12-5.20.7.3-sources.jar: zio/aws/resourcegroups/model/GetGroupQueryRequest.scala <==
package zio.aws.resourcegroups.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.resourcegroups.model.primitives.{GroupString, GroupName}
import scala.jdk.CollectionConverters._
final case class GetGroupQueryRequest(
    groupName: Optional[GroupName] = Optional.Absent,
    group: Optional[GroupString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest = {
    import GetGroupQueryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest
      .builder()
      .optionallyWith(
        groupName.map(value => GroupName.unwrap(value): java.lang.String)
      )(_.groupName)
      .optionallyWith(
        group.map(value => GroupString.unwrap(value): java.lang.String)
      )(_.group)
      .build()
  }
  def asReadOnly: zio.aws.resourcegroups.model.GetGroupQueryRequest.ReadOnly =
    zio.aws.resourcegroups.model.GetGroupQueryRequest.wrap(buildAwsValue())
}
object GetGroupQueryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.resourcegroups.model.GetGroupQueryRequest =
      zio.aws.resourcegroups.model.GetGroupQueryRequest(
        groupName.map(value => value),
        group.map(value => value)
      )
    def groupName: Optional[GroupName]
    def group: Optional[GroupString]
    def getGroupName: ZIO[Any, AwsError, GroupName] =
      AwsError.unwrapOptionField("groupName", groupName)
    def getGroup: ZIO[Any, AwsError, GroupString] =
      AwsError.unwrapOptionField("group", group)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest
  ) extends zio.aws.resourcegroups.model.GetGroupQueryRequest.ReadOnly {
    override val groupName: Optional[GroupName] = zio.aws.core.internal
      .optionalFromNullable(impl.groupName())
      .map(value => zio.aws.resourcegroups.model.primitives.GroupName(value))
    override val group: Optional[GroupString] = zio.aws.core.internal
      .optionalFromNullable(impl.group())
      .map(value => zio.aws.resourcegroups.model.primitives.GroupString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.resourcegroups.model.GetGroupQueryRequest
  ): zio.aws.resourcegroups.model.GetGroupQueryRequest.ReadOnly = new Wrapper(
    impl
  )
}
